@@ -46,23 +46,23 @@
 #'                      conf.int = FALSE,
 #'                      color = c("Dark2"))
 TCGAanalyze_survival <- function(
-    data,
-    clusterCol = NULL,
-    legend = "Legend",
-    labels = NULL,
-    risk.table = TRUE,
-    xlim = NULL,
-    main = "Kaplan-Meier Overall Survival Curves",
-    ylab = "Probability of survival",
-    xlab = "Time since diagnosis (days)",
-    filename = "survival.pdf",
-    color = NULL,
-    height = 8,
-    width = 12,
-    dpi = 300,
-    pvalue = TRUE,
-    conf.int = TRUE,
-    ...) {
+        data,
+        clusterCol = NULL,
+        legend = "Legend",
+        labels = NULL,
+        risk.table = TRUE,
+        xlim = NULL,
+        main = "Kaplan-Meier Overall Survival Curves",
+        ylab = "Probability of survival",
+        xlab = "Time since diagnosis (days)",
+        filename = "survival.pdf",
+        color = NULL,
+        height = 8,
+        width = 12,
+        dpi = 300,
+        pvalue = TRUE,
+        conf.int = TRUE,
+        ...) {
     .e <- environment()
 
     check_package("survminer")
@@ -272,33 +272,33 @@ TCGAanalyze_survival <- function(
 #' TCGAvisualize_meanMethylation(data,groupCol  = "group",sort="median.asc",filename="medianasc.pdf")
 #' TCGAvisualize_meanMethylation(data,groupCol  = "group",sort="median.desc",filename="mediandesc.pdf")
 TCGAvisualize_meanMethylation <- function(
-    data,
-    groupCol = NULL,
-    subgroupCol = NULL,
-    shapes = NULL,
-    print.pvalue = FALSE,
-    plot.jitter = TRUE,
-    jitter.size = 3,
-    filename = "groupMeanMet.pdf",
-    ylab = expression(paste("Mean DNA methylation (",
-                            beta, "-values)")),
-    xlab = NULL,
-    title = "Mean DNA methylation",
-    labels = NULL,
-    group.legend = NULL,
-    subgroup.legend = NULL,
-    color = NULL,
-    y.limits = NULL,
-    sort,
-    order,
-    legend.position = "top",
-    legend.title.position = "top",
-    legend.ncols = 3,
-    add.axis.x.text = TRUE,
-    width = 10,
-    height = 10,
-    dpi = 600,
-    axis.text.x.angle = 90) {
+        data,
+        groupCol = NULL,
+        subgroupCol = NULL,
+        shapes = NULL,
+        print.pvalue = FALSE,
+        plot.jitter = TRUE,
+        jitter.size = 3,
+        filename = "groupMeanMet.pdf",
+        ylab = expression(paste("Mean DNA methylation (",
+                                beta, "-values)")),
+        xlab = NULL,
+        title = "Mean DNA methylation",
+        labels = NULL,
+        group.legend = NULL,
+        subgroup.legend = NULL,
+        color = NULL,
+        y.limits = NULL,
+        sort,
+        order,
+        legend.position = "top",
+        legend.title.position = "top",
+        legend.ncols = 3,
+        add.axis.x.text = TRUE,
+        width = 10,
+        height = 10,
+        dpi = 600,
+        axis.text.x.angle = 90) {
     .e <- environment()
     mean <- colMeans(assay(data), na.rm = TRUE)
 
@@ -553,14 +553,14 @@ TCGAvisualize_meanMethylation <- function(
 #' @importFrom stats wilcox.test
 #' @keywords internal
 dmc.non.parametric.se <- function(
-    data,
-    groupCol = NULL,
-    group1 = NULL,
-    group2 = NULL,
-    paired = FALSE,
-    adj.method = "BH",
-    alternative = "two.sided",
-    cores = 1
+        data,
+        groupCol = NULL,
+        group1 = NULL,
+        group2 = NULL,
+        paired = FALSE,
+        adj.method = "BH",
+        alternative = "two.sided",
+        cores = 1
 ) {
 
     if (is.null(groupCol)) {
@@ -630,13 +630,13 @@ dmc.non.parametric.se <- function(
 #'  )
 #'  TCGAbiolinks:::dmc.non.parametric(counts,1:10,11:20)
 dmc.non.parametric <-  function(
-    matrix,
-    idx1 = NULL,
-    idx2 = NULL,
-    paired = FALSE,
-    adj.method = "BH",
-    alternative = "two.sided",
-    cores = 1)
+        matrix,
+        idx1 = NULL,
+        idx2 = NULL,
+        paired = FALSE,
+        adj.method = "BH",
+        alternative = "two.sided",
+        cores = 1)
 {
     parallel <- set_cores(cores)
 
@@ -748,28 +748,28 @@ dmc.non.parametric <-  function(
 #' }
 #' while (!(is.null(dev.list()["RStudioGD"]))){dev.off()}
 TCGAVisualize_volcano <- function(
-    x,
-    y,
-    filename = "volcano.pdf",
-    ylab =  expression(paste(-Log[10]," (FDR corrected -P values)")),
-    xlab = NULL,
-    title = "Volcano plot",
-    legend = NULL,
-    label = NULL,
-    xlim = NULL,
-    ylim = NULL,
-    color = c("black", "red", "green"),
-    names = NULL,
-    names.fill = TRUE,
-    show.names = "significant",
-    x.cut = 0,
-    y.cut = 0.01,
-    height = 5,
-    width = 10,
-    highlight = NULL,
-    highlight.color = "orange",
-    names.size = 4,
-    dpi = 300)
+        x,
+        y,
+        filename = "volcano.pdf",
+        ylab =  expression(paste(-Log[10]," (FDR corrected -P values)")),
+        xlab = NULL,
+        title = "Volcano plot",
+        legend = NULL,
+        label = NULL,
+        xlim = NULL,
+        ylim = NULL,
+        color = c("black", "red", "green"),
+        names = NULL,
+        names.fill = TRUE,
+        show.names = "significant",
+        x.cut = 0,
+        y.cut = 0.01,
+        height = 5,
+        width = 10,
+        highlight = NULL,
+        highlight.color = "orange",
+        names.size = 4,
+        dpi = 300)
 {
     if (!is.null(names)) {
         if (all(grepl("\\|", names))) {
@@ -797,7 +797,7 @@ TCGAVisualize_volcano <- function(
 
     # If x.cut
     if (length(x.cut) == 1) {
-        x.cut.min <- -x.cut
+        x.cut.min <- -1 * x.cut
         x.cut.max <- x.cut
     }
     if (length(x.cut) == 2) {
@@ -1053,29 +1053,29 @@ TCGAVisualize_volcano <- function(
 #'   group2 = "group_2"
 #' )
 TCGAanalyze_DMC <- function(
-    data,
-    groupCol = NULL,
-    group1 = NULL,
-    group2 = NULL,
-    alternative = "two.sided",
-    diffmean.cut = 0.2,
-    paired = FALSE,
-    adj.method = "BH",
-    plot.filename = "methylation_volcano.pdf",
-    ylab =  expression(paste(-Log[10], " (FDR corrected -P values)")),
-    xlab =  expression(paste("DNA Methylation difference (", beta, "-values)")),
-    title = NULL,
-    legend = "Legend",
-    color = c("black",  "red", "darkgreen"),
-    label = NULL,
-    xlim = NULL,
-    ylim = NULL,
-    p.cut = 0.01,
-    probe.names = FALSE,
-    cores = 1,
-    save = TRUE,
-    save.directory = ".",
-    filename = NULL)
+        data,
+        groupCol = NULL,
+        group1 = NULL,
+        group2 = NULL,
+        alternative = "two.sided",
+        diffmean.cut = 0.2,
+        paired = FALSE,
+        adj.method = "BH",
+        plot.filename = "methylation_volcano.pdf",
+        ylab =  expression(paste(-Log[10], " (FDR corrected -P values)")),
+        xlab =  expression(paste("DNA Methylation difference (", beta, "-values)")),
+        title = NULL,
+        legend = "Legend",
+        color = c("black",  "red", "darkgreen"),
+        label = NULL,
+        xlim = NULL,
+        ylim = NULL,
+        p.cut = 0.01,
+        probe.names = FALSE,
+        cores = 1,
+        save = TRUE,
+        save.directory = ".",
+        filename = NULL)
 {
     names(color) <- as.character(1:3)
     # Check if object is a summarized Experiment
@@ -1246,7 +1246,8 @@ TCGAanalyze_DMC <- function(
 #' Execute volcanoPlot function in order to obtain these values for the object.
 #' @param exp Object obtained by DEArnaSEQ function
 #' @param filename The filename of the file (it can be pdf, svg, png, etc)
-#' @param met.platform DNA methylation platform ("27K","450K" or "EPIC")
+#' @param met.platform DNA methylation platform  "Illumina Human Methylation 450",
+#' "Illumina Human Methylation 27", "Illumina Methylation Epic"
 #' @param genome Genome of reference ("hg38" or "hg19") used to identify nearest probes TSS
 #' @param legend legend title
 #' @param color vector of colors to be used in graph
@@ -1283,7 +1284,10 @@ TCGAanalyze_DMC <- function(
 #' @examples
 #' \dontrun{
 #' library(SummarizedExperiment)
-#' met <- TCGAbiolinks:::getMetPlatInfo(genome = "hg38", platform = "27K")
+#' met <- TCGAbiolinks:::getMetPlatInfo(
+#'    genome = "hg38",
+#'    platform = "Illumina Human Methylation 27"
+#'  )
 #' values(met) <- NULL
 #' met$probeID <- names(met)
 #' nrows <- length(met); ncols <- 20
@@ -1296,7 +1300,8 @@ TCGAanalyze_DMC <- function(
 #' met <- SummarizedExperiment::SummarizedExperiment(
 #'          assays = S4Vectors::SimpleList(counts=counts),
 #'          rowRanges = met,
-#'          colData = colData)
+#'          colData = colData
+#' )
 #' rowRanges(met)$diffmean.g1.g2 <- c(runif(nrows, -0.1, 0.1))
 #' rowRanges(met)$diffmean.g2.g1 <- -1*(rowRanges(met)$diffmean.g1.g2)
 #' rowRanges(met)$p.value.g1.g2 <- c(runif(nrows, 0, 1))
@@ -1314,56 +1319,60 @@ TCGAanalyze_DMC <- function(
 #'   group1 = "g1",
 #'   group2 = "g2",
 #'   genome = "hg38",
-#'   met.platform = "27K",
+#'   met.platform = "27k",
 #'   diffmean.cut = 0.0,
 #'   names  = TRUE
 #' )
 #' }
 TCGAvisualize_starburst <- function(
-    met,
-    exp,
-    group1 = NULL,
-    group2 = NULL,
-    exp.p.cut = 0.01,
-    met.p.cut = 0.01,
-    diffmean.cut = 0,
-    logFC.cut = 0,
-    met.platform,
-    genome,
-    names = FALSE,
-    names.fill = TRUE,
-    filename = "starburst.pdf",
-    return.plot = FALSE,
-    ylab = expression(atop("Gene Expression",
-                           paste(Log[10],
-                                 " (FDR corrected P values)"))),
-    xlab = expression(atop("DNA Methylation",
-                           paste(Log[10],
-                                 " (FDR corrected P values)"))),
-    title = "Starburst Plot",
-    legend = "DNA Methylation/Expression Relation",
-    color = NULL,
-    label = c(
-        "Not Significant",
-        "Up regulated & Hypo methylated",
-        "Down regulated & Hypo methylated",
-        "hypo methylated",
-        "hyper methylated",
-        "Up regulated",
-        "Down regulated",
-        "Up regulated & Hyper methylated",
-        "Down regulated & Hyper methylated"
-    ),
-    xlim = NULL,
-    ylim = NULL,
-    height = 10,
-    width = 20,
-    dpi = 600
+        met,
+        exp,
+        group1 = NULL,
+        group2 = NULL,
+        exp.p.cut = 0.01,
+        met.p.cut = 0.01,
+        diffmean.cut = 0,
+        logFC.cut = 0,
+        met.platform = c(
+            "Illumina Human Methylation 450",
+            "Illumina Human Methylation 27",
+            "Illumina Methylation Epic"
+        ),
+        genome,
+        names = FALSE,
+        names.fill = TRUE,
+        filename = "starburst.png",
+        return.plot = FALSE,
+        ylab = expression(atop("Gene Expression",
+                               paste(-Log[10],
+                                     " (FDR corrected P values)"))),
+        xlab = expression(atop("DNA Methylation",
+                               paste(-Log[10],
+                                     " (FDR corrected P values)"))),
+        title = "Starburst Plot",
+        legend = "DNA Methylation/Expression Relation",
+        color = NULL,
+        label = c(
+            "Not Significant",
+            "Up regulated & Hypo methylated",
+            "Down regulated & Hypo methylated",
+            "hypo methylated",
+            "hyper methylated",
+            "Up regulated",
+            "Down regulated",
+            "Up regulated & Hyper methylated",
+            "Down regulated & Hyper methylated"
+        ),
+        xlim = NULL,
+        ylim = NULL,
+        height = 10,
+        width = 20,
+        dpi = 600
 ) {
-    if (missing(genome))
-        stop("Please set genome (hg19 or hg38)")
-    if (missing(met.platform))
-        stop("Please set met.platform (EPIC, 450K or 27K)")
+    if (missing(genome)) stop("Please set genome (hg19 or hg38)")
+    if (missing(met.platform)) stop("Please set met.platform (EPIC, 450k or 27k)")
+
+    met.platform <- match.arg(met.platform)
 
     .e <- environment()
 
@@ -1427,15 +1436,10 @@ TCGAvisualize_starburst <- function(
     }
 
     # Preparing methylation
-    pcol <-
-        gsub("[[:punct:]]| ",
-             ".",
-             paste("p.value.adj", group1, group2, sep = "."))
+    pcol <-gsub("[[:punct:]]| ", ".", paste("p.value.adj", group1, group2, sep = "."))
+
     if (!(pcol %in%  colnames(met))) {
-        pcol <-
-            gsub("[[:punct:]]| ",
-                 ".",
-                 paste("p.value.adj", group2, group1, sep = "."))
+        pcol <-gsub("[[:punct:]]| ",  ".",  paste("p.value.adj", group2, group1, sep = "."))
     }
     if (!(pcol %in%  colnames(met))) {
         stop("Error! p-values adjusted not found. Please, run TCGAanalyze_DMR")
@@ -1453,27 +1457,13 @@ TCGAvisualize_starburst <- function(
         if (grepl("ENSG", rownames(exp)[1])) {
             exp$ensembl_gene_id <- rownames(exp)
         } else {
-            # We will consider our rownames has the gene symbol
-            gene.info <- get.GRCh.bioMart(genome)
-            if (any(sapply(rownames(exp)[1:10], function(y)
-                any(grepl(
-                    y, gene.info[, grep("external_gene_", colnames(gene.info))]
-                ))))) {
-                idx <-
-                    match(rownames(exp), gene.info[, grep("external_gene_", colnames(gene.info))])
-                exp <- exp[!is.na(idx), ]
-                idx <-
-                    match(rownames(exp), gene.info[, grep("external_gene_", colnames(gene.info))])
-                exp$ensembl_gene_id <-
-                    gene.info[idx, "ensembl_gene_id"]
-            }
+            stop("rownames or first column must be gene ensembl IDs")
         }
-
     }
 
-    if (!"probeID" %in% colnames(met))
+    if (!"probeID" %in% colnames(met)){
         met$probeID <- met$Composite.Element.REF
-
+    }
 
     # Check if gene symbol columns exists
     if (!"ensembl_gene_id" %in% colnames(exp)) {
@@ -1487,39 +1477,22 @@ TCGAvisualize_starburst <- function(
     message("o Fetching auxiliary information")
     message("oo Fetching probes genomic information")
     met.info <- getMetPlatInfo(genome = genome, platform = met.platform)
-    values(met.info) <- NULL
-    message("oo Fetching TSS information")
-    tss <- getTSS(genome = genome)
-    tss <- promoters(tss, upstream = 0, downstream = 0)
-    message("o Mapping probes to nearest TSS")
-    dist <- distanceToNearest(tss, met.info)
-    g <- suppressWarnings(as.data.frame(tss[queryHits(dist)]))
-    g$start_position <- NULL
-    g$end_position <- NULL
-    colnames(g)[1:5] <- paste0("gene_", colnames(g)[1:5])
-    m <- suppressWarnings(as.data.frame(met.info[subjectHits(dist)], row.names = NULL))
-    colnames(m) <- paste0("probe_", colnames(m))
-    m$probeID <- names(met.info[subjectHits(dist)])
-    nearest <- cbind(m, g)
-    nearest$distance_TSS <- values(dist)$distance
-    # Keep only one entry
-    nearest$id <- paste0(nearest$probeID, nearest$ensembl_gene_id)
-    nearest <- nearest[order(nearest$id, -abs(nearest$distance_TSS)),]
-    nearest <- nearest[!duplicated(nearest$id),]
-    nearest$id <- NULL
-    nearest <- nearest[, c("distance_TSS", "probeID", "ensembl_gene_id")]
-    # END mapping nearest probe to nearest gene
-    message("o Mapping results information")
-    volcano <- plyr::join(nearest, exp, by = "ensembl_gene_id")
-    volcano <- merge(volcano, met, by = "probeID")
+    cpg.target.gene <- data.frame("probeID" = names(met.info),"gene_name" = met.info$gene_HGNC) %>%
+        tidyr::separate_rows(gene_name,sep = ";") %>% na.omit()
 
-    volcano$ID <- paste(volcano$ensembl_gene_id, volcano$probeID, sep = ".")
+    message("o Mapping results information")
+    volcano <- cpg.target.gene %>%
+        dplyr::inner_join(exp[,c("gene_name","logFC","FDR")], by = "gene_name") %>%
+        dplyr::inner_join(met %>% tibble::as_tibble(), by = "probeID")
+
+    volcano$ID <- paste(volcano$gene_name, volcano$probeID, sep = ".")
     volcano <- volcano[!is.na(volcano$FDR), ] # Some genes have no values
     # Preparing gene expression
-    volcano$geFDR <- log10(volcano$FDR)
+    volcano$geFDR <- -1 * log10(volcano$FDR)
     volcano$geFDR2 <- volcano$geFDR
-    volcano[volcano$logFC > 0, "geFDR2"] <-
-        -1 * volcano[volcano$logFC > 0, "geFDR"]
+
+
+    volcano[volcano$logFC > 0, "geFDR2"] <- -1 * volcano[volcano$logFC > 0, "geFDR"]
 
     # Preparing DNA methylation
     diffcol <- gsub(
@@ -1527,7 +1500,7 @@ TCGAvisualize_starburst <- function(
         ".",
         paste("diffmean", group1, group2, sep = ".")
     )
-    volcano$meFDR <- log10(volcano[, pcol])
+    volcano$meFDR <- -1 * log10(volcano[, pcol,drop =T])
     volcano$meFDR2 <- volcano$meFDR
     idx <- volcano[, diffcol] > 0
     idx[is.na(idx)] <- FALSE # handling NAs
@@ -1546,77 +1519,71 @@ TCGAvisualize_starburst <- function(
     volcano <- suppressWarnings(tibble::as.tibble(volcano))
 
     # Group 2:up regulated and hypomethylated
-    a <- dplyr::filter(
-        volcano,
-        volcano$geFDR2 > exp.upperthr &
-            volcano$meFDR2 < met.lowerthr &
-            abs(volcano[, diffcol]) > diffmean.cut &
-            abs(volcano$logFC) > logFC.cut
+    a <- volcano %>% dplyr::filter(
+        geFDR2 > exp.upperthr &
+            logFC > logFC.cut &
+            meFDR2 < met.lowerthr &
+            abs(!!as.name(diffcol)) > diffmean.cut
     )
 
     # Group 3: down regulated and hypomethylated
-    b <- dplyr::filter(
-        volcano,
-        volcano$geFDR2 < exp.lowerthr &
-            volcano$meFDR2 < met.lowerthr &
-            abs(volcano[, diffcol]) > diffmean.cut &
-            volcano$logFC < logFC.cut
+    b <- volcano %>% dplyr::filter(
+        geFDR2 < exp.lowerthr &
+            logFC > logFC.cut &
+            meFDR2 < met.lowerthr &
+            abs(!!as.name(diffcol)) > diffmean.cut
     )
 
+
     # Group 4: hypomethylated
-    c <- dplyr::filter(
-        volcano,
-        volcano$geFDR2 > exp.lowerthr &
-            volcano$geFDR2 < exp.upperthr &
-            volcano$meFDR2 < met.lowerthr &
-            abs(volcano[, diffcol]) > diffmean.cut
+    c <- volcano %>% dplyr::filter(
+        geFDR2 > exp.lowerthr &
+            geFDR2 < exp.upperthr &
+            meFDR2 < met.lowerthr &
+            abs(!!as.name(diffcol)) > diffmean.cut
     )
 
     # Group 5: hypermethylated
-    d <- dplyr::filter(
-        volcano,
-        volcano$geFDR2 > exp.lowerthr &
-            volcano$geFDR2 < exp.upperthr &
-            volcano$meFDR2 > met.upperthr &
-            abs(volcano[, diffcol]) > diffmean.cut
+    d <- volcano %>% dplyr::filter(
+        geFDR2 > exp.lowerthr &
+            geFDR2 < exp.upperthr &
+            meFDR2 > met.upperthr &
+            abs(!!as.name(diffcol)) > diffmean.cut
     )
 
     # Group 6: upregulated
-    e <- dplyr::filter(
-        volcano,
-        volcano$geFDR2 > exp.upperthr &
-            volcano$meFDR2 < met.upperthr &
-            volcano$meFDR2 > met.lowerthr &
-            volcano$logFC > logFC.cut
+    e <- volcano %>% dplyr::filter(
+        geFDR2 > exp.upperthr &
+            meFDR2 < met.upperthr &
+            meFDR2 > met.lowerthr &
+            logFC > logFC.cut
     )
 
     # Group 7: downregulated
-    f <- dplyr::filter(
-        volcano,
-        volcano$geFDR2 < exp.lowerthr &
-            volcano$meFDR2 < met.upperthr &
-            volcano$meFDR2 > met.lowerthr &
-            abs(volcano$logFC) > logFC.cut
+    f <- volcano %>% dplyr::filter(
+        geFDR2 < exp.lowerthr &
+            abs(logFC) > logFC.cut &
+            meFDR2 < met.upperthr &
+            meFDR2 > met.lowerthr
     )
 
     # Group 8: upregulated and hypermethylated
-    g <- dplyr::filter(
-        volcano,
-        volcano$geFDR2 > exp.upperthr &
-            volcano$meFDR2 > met.upperthr &
-            abs(volcano[, diffcol]) > diffmean.cut &
-            volcano$logFC > logFC.cut
+    g <- volcano %>% dplyr::filter(
+        geFDR2 > exp.upperthr &
+            logFC > logFC.cut &
+            meFDR2 > met.upperthr &
+            abs(!!as.name(diffcol)) > diffmean.cut
     )
 
-    # Group 9: downregulated and hypermethylated
-    h <- dplyr::filter(
-        volcano,
-        volcano$geFDR2 < exp.lowerthr &
-            volcano$meFDR2 > met.upperthr &
-            abs(volcano[, diffcol]) > diffmean.cut &
-            volcano$logFC < logFC.cut
+    # Group 9: downregulated and hypermethylated in group 2
+    h <-  volcano %>% dplyr::filter(
+        geFDR2 < exp.lowerthr &
+            logFC > logFC.cut &
+            meFDR2 > met.upperthr &
+            abs(!!as.name(diffcol)) > diffmean.cut
     )
 
+
     groups <- as.character(seq(2, 9))
 
     # return methylation < 0, expression > 0
@@ -1668,9 +1635,9 @@ TCGAvisualize_starburst <- function(
         data = volcano.aux,
         environment = .e,
         aes(
-            x = volcano.aux$meFDR2,
-            y = volcano.aux$geFDR2,
-            colour = volcano.aux$threshold.starburst
+            x = meFDR2,
+            y = geFDR2,
+            colour = threshold.starburst
         )
     ) + geom_point()
 
@@ -1681,10 +1648,10 @@ TCGAvisualize_starburst <- function(
             p <- p + ggrepel::geom_label_repel(
                 data = significant,
                 aes(
-                    x = significant$meFDR2,
-                    y =  significant$geFDR2,
-                    label = map.ensg(genome, significant$ensembl_gene_id)$external_gene_name,
-                    fill = as.factor(significant$starburst.status)
+                    x = meFDR2,
+                    y =  geFDR2,
+                    label = gene_name,
+                    fill = as.factor(starburst.status)
                 ),
                 size = 4,
                 show.legend = FALSE,
@@ -1697,10 +1664,10 @@ TCGAvisualize_starburst <- function(
             p <- p + ggrepel::geom_text_repel(
                 data = significant,
                 aes(
-                    x = significant$meFDR2,
-                    y =  significant$geFDR2,
-                    label = map.ensg(genome, significant$ensembl_gene_id)$external_gene_name,
-                    fill = significant$starburst.status
+                    x = meFDR2,
+                    y =  geFDR2,
+                    label = gene_name,
+                    fill = starburst.status
                 ),
                 size = 4,
                 show.legend = FALSE,
@@ -1720,24 +1687,25 @@ TCGAvisualize_starburst <- function(
         p <- p + ylim(ylim)
     }
     p <- p + ggtitle(title) + ylab(ylab) + xlab(xlab) + guides(size = FALSE)
-    p <- p + scale_color_manual(values = color,
-                                labels = label,
-                                name = legend) +
+    p <- p + scale_color_manual(values = color, labels = label, name = legend) +
         guides(col = guide_legend(nrow = 3))
 
-    p <-
-        p + geom_hline(aes(yintercept = exp.lowerthr),
-                       colour = "black",
-                       linetype = "dashed") +
+    p <- p + geom_hline(aes(yintercept = exp.lowerthr),
+                        colour = "black",
+                        linetype = "dashed"
+    ) +
         geom_hline(aes(yintercept = exp.upperthr),
                    colour = "black",
-                   linetype = "dashed") +
+                   linetype = "dashed"
+        ) +
         geom_vline(aes(xintercept = met.lowerthr),
                    colour = "black",
-                   linetype = "dashed") +
+                   linetype = "dashed"
+        ) +
         geom_vline(aes(xintercept = met.upperthr),
                    colour = "black",
-                   linetype = "dashed")  +
+                   linetype = "dashed"
+        )  +
         theme_bw() +
         theme(
             panel.border = element_blank(),
@@ -1762,13 +1730,15 @@ TCGAvisualize_starburst <- function(
                                         size = 14),
             axis.text.y = element_text(size = 14)
         )
-    if (!return.plot)
+    if (!return.plot){
+        message("Saving figure as ", filename)
         ggsave(
             filename = filename,
             width = width,
             height = height,
             dpi = dpi
         )
+    }
     volcano$shape <- NULL
     volcano$threshold.starburst <- NULL
     volcano$threshold.size <- NULL
@@ -1792,7 +1762,7 @@ TCGAvisualize_starburst <- function(
     message(
         "oo It contains pair with changes both in the expression level of the nearest gene and  in the DNA methylation level"
     )
-    suppressWarnings(write_csv(x = volcano, path = "starburst_results.csv"))
+    readr::write_csv(x = volcano, file = "starburst_results.csv")
 
     if (return.plot) {
         return(list(plot = p, starburst = volcano))
@@ -1804,36 +1774,38 @@ TCGAvisualize_starburst <- function(
 
 #' @title Get DNA methylation array metadata from SesameData
 #' @noRd
+#' @importFrom stringr str_c
 getMetPlatInfo <- function(
-    genome = c("hg38","hg19"),
-    platform = c("450k","EPIC","27k")
+        genome = c("hg38","hg19"),
+        platform = c(
+            "Illumina Human Methylation 450",
+            "Illumina Human Methylation 27",
+            "Illumina Methylation Epic"
+        )
 ){
     genome <- match.arg(genome)
-    # arrayType <- match.arg(arrayType)
-
-    platform <-  switch(
-        platform,
-        "450K" = "HM450",
-        "450k" = "HM450",
-        "27k"  = "HM27",
-        "27K"  = "HM27",
-        "EPIC" = "EPIC"
-    )
-    if (is.null(platform)) {
-        stop("platform must one of the following options: 450k, EPIC or 27k")
-    }
+    arrayType <- match.arg(platform)
 
     check_package("sesameData")
     check_package("sesame")
+    check_package("AnnotationHub")
+    check_package("ExperimentHub")
 
-    sesameData::sesameDataCacheAll()
-    sesameData::sesameDataGet(
-        str_c(
-            platform,
-            ".",
-            genome,
-            ".manifest"
-        )
+    if(arrayType == "Illumina Human Methylation 450") arrayType <- "HM450"
+    if(arrayType == "Illumina Human Methylation 27") arrayType <- "HM27"
+    if(arrayType == "Illumina Methylation Epic") arrayType <- "EPIC"
+
+    message("Accessing DNAm annotation from sesame package for: ", genome, " - ",arrayType)
+    manifest <-  str_c(
+        arrayType,
+        ".",
+        genome,
+        ".manifest"
     )
+    ehub <- ExperimentHub::ExperimentHub()
+    query <- AnnotationHub::query(ehub, c("sesameData",manifest))
+    query <- query[query$title == manifest,]
+    ah_id <- query$ah_id[query$rdatadateadded == max(as.Date(query$rdatadateadded))]
+    ehub[[ah_id]]
 }
 
